@@ -12,7 +12,7 @@ pub fn emit_diagnostics(env: &BaseHostEnvironment, bytes_ptr: i32, bytes_ptr_len
                 let diagnostics_bytes = copy_bytes_into_host(memory, bytes_ptr, bytes_ptr_len);
                 let serialized = Serialized::new_for_plugin(&diagnostics_bytes[..], bytes_ptr_len);
                 let diagnostic = Serialized::deserialize::<Diagnostic>(&serialized)
-                    .expect("Should able to be deserialized into diagnsotic");
+                    .expect("Should able to be deserialized into diagnostic");
 
                 let mut builder =
                     swc_common::errors::DiagnosticBuilder::new_diagnostic(handler, diagnostic);
